#
# Online Timesheet Product
#
# (C) Copyright 2001 The Internet (Aust) Pty Ltd
# ACN: 082 081 472  ABN: 83 082 081 472
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#
# Author: Andrew Milton <akm@theinternet.com.au>

import string
from Globals import DTMLFile
import Acquisition

import zLOG

def log(message,summary='',severity=0):
	                zLOG.LOG('MyDebugLog',severity,summary,message)

def manage_addProject(self, client_id, name, start_date,
					  estimated_end_date, estimated_hours, 
					  project_description, isbillable=1, bill_rate=None,
					  REQUEST={}):

	""" Add a new Project """

	# Use the default bill rate for the client
	if bill_rate is None:
		c = self.getClientFromId(client_id)
		bill_rate=c.default_bill_rate
		
	self.sqlInsertProject(client_id=client_id, project_name=name,
						  start_date=start_date,
						  estimated_end_date=estimated_end_date,
						  estimated_hours=estimated_hours, bill_rate=bill_rate,
						  project_description=project_description,
						  isbillable=isbillable)

	if REQUEST:
		return self.manage_main(self, REQUEST)
	return ''

manage_addProjectForm=DTMLFile('manage_addProjectForm', globals())
manage_editProjectForm=DTMLFile('manage_editProjectForm', globals())

def manage_editProject(self, name, estimated_end_date,
					   estimated_hours, project_id,
					   project_description, isbillable=1,
					   REQUEST={}):

	""" Add a new Project """

	self.sqlUpdateProject(project_name=name,
						  estimated_end_date=estimated_end_date,
						  estimated_hours=estimated_hours,
						  project_description=project_description,
						  isbillable=isbillable,
						  project_id=project_id)

	members_assigned = [{'member_id':member['member_id']} for member in self.getProjectMembers(project_id)]
        members=REQUEST.get('member_ids', [])

	for member_id in members:
		member = [member for member in REQUEST.get('members') if member['id']==member_id][0]
		if member not in members_assigned:
    		    self.addMemberToProject(project_id, member_id, member['billrate'], 1, None)
		    
	remove_members = [ member.get('member_id') for member in members_assigned if member.get('member_id') not in members ]

	for member in remove_members:
		self.removeMemberFromProject(project_id, member, None)

	if REQUEST:
		return self.manage_main(self, REQUEST)
	return ''


class Project(Acquisition.Implicit):
	""" A Project to which you can book hours """
	def __init__(self, project_id, client_id, project_name, start_date,
				 estimated_end_date, estimated_hours, bill_rate,
				 project_description, isbillable,
				 actual_end_date='', status=0):
		self.project_id=project_id
		self.client_id=client_id
		self.project_name=project_name
		self.start_date=start_date
		self.estimated_end_date=estimated_end_date
		self.estimated_hours=estimated_hours
		self.bill_rate=bill_rate
		self.project_description=project_description
		self.isbillable=isbillable
		self.actual_end_date=actual_end_date
		self.status=status
		
	def getMembers(self):
		return self.sqlGetProjectMembers(project_id=self.project_id)
