--
-- Selected TOC Entries:
--
--
-- TOC Entry ID 2 (OID 123638)
--
-- Name: clients_client_id_seq Type: SEQUENCE Owner: akm
--

CREATE SEQUENCE "clients_client_id_seq" start 1 increment 1 maxvalue 2147483647 minvalue 1  cache 1 ;

--
-- TOC Entry ID 6 (OID 123657)
--
-- Name: clients Type: TABLE Owner: akm
--

CREATE TABLE "clients" (
	"client_id" integer DEFAULT nextval('"clients_client_id_seq"'::text) NOT NULL,
	"client_name" character varying(64) NOT NULL,
	"default_bill_rate" numeric(12,2),
	"address_line" character varying(64),
	"city" character varying(32),
	"state" character varying(32),
	"postcode" character varying(16),
	"country" character varying(32),
	Constraint "clients_pkey" Primary Key ("client_id")
);

--
-- TOC Entry ID 3 (OID 123678)
--
-- Name: projects_project_id_seq Type: SEQUENCE Owner: akm
--

CREATE SEQUENCE "projects_project_id_seq" start 1 increment 1 maxvalue 2147483647 minvalue 1  cache 1 ;

--
-- TOC Entry ID 7 (OID 123697)
--
-- Name: projects Type: TABLE Owner: akm
--

CREATE TABLE "projects" (
	"project_id" integer DEFAULT nextval('"projects_project_id_seq"'::text) NOT NULL,
	"client_id" integer NOT NULL,
	"project_name" character varying(64) NOT NULL,
	"start_date" date,
	"estimated_end_date" date,
	"actual_end_date" date,
	"estimated_hours" integer,
	"bill_rate" numeric(12,2) DEFAULT 0,
	"project_description" character varying(256),
	"isbillable" integer DEFAULT 1,
	"status" integer,
	Constraint "projects_pkey" Primary Key ("project_id")
);

--
-- TOC Entry ID 8 (OID 123752)
--
-- Name: project_members Type: TABLE Owner: akm
--

CREATE TABLE "project_members" (
	"project_id" integer NOT NULL,
	"member_id" character varying(64) NOT NULL,
	"is_manager" integer DEFAULT 0 NOT NULL,
	"bill_rate" numeric(12,2)
);

--
-- TOC Entry ID 4 (OID 123851)
--
-- Name: categories_category_id_seq Type: SEQUENCE Owner: akm
--

CREATE SEQUENCE "categories_category_id_seq" start 1 increment 1 maxvalue 2147483647 minvalue 1  cache 1 ;

--
-- TOC Entry ID 9 (OID 123870)
--
-- Name: categories Type: TABLE Owner: akm
--

CREATE TABLE "categories" (
	"category_id" integer DEFAULT nextval('"categories_category_id_seq"'::text) NOT NULL,
	"category_name" character varying(64) NOT NULL,
	"is_billable" integer NOT NULL,
	Constraint "categories_pkey" Primary Key ("category_id")
);

--
-- TOC Entry ID 10 (OID 123891)
--
-- Name: hours Type: TABLE Owner: akm
--

CREATE TABLE "hours" (
	"hours_id" integer DEFAULT nextval('"hours_hours_id_seq"'::text) NOT NULL,
	"project_id" integer NOT NULL,
	"client_id" integer NOT NULL,
	"member_id" character varying(64) NOT NULL,
	"hours_date" date NOT NULL,
	"date_entered" date NOT NULL,
	"total_hours" real NOT NULL,
	"billable" integer DEFAULT 1 NOT NULL,
	"comments" text,
	"approved_by" character varying(64),
	"approved_on" date,
	"year" integer,
	"week" integer,
	"dow" integer,
	"status" integer,
	"category_id" integer,
	Constraint "hours_pkey" Primary Key ("hours_id")
);

--
-- TOC Entry ID 5 (OID 123939)
--
-- Name: hours_hours_id_seq Type: SEQUENCE Owner: akm
--

CREATE SEQUENCE "hours_hours_id_seq" start 1 increment 1 maxvalue 2147483647 minvalue 1  cache 1 ;

--
-- TOC Entry ID 11 (OID 124171)
--
-- Name: timesheet Type: VIEW Owner: akm
--

CREATE VIEW "timesheet" as SELECT mon.project_id, mon.client_id, mon.member_id, mon.hours_date, mon.date_entered, mon.total_hours AS mon_hours, mon.billable, mon.comments, mon.approved_by, mon.approved_on, mon."year", mon.week, mon.status, mon.category_id, tue.total_hours AS tue_hours, wed.total_hours AS wed_hours, thu.total_hours AS thu_hours, fri.total_hours AS fri_hours, sat.total_hours AS sat_hours, sun.total_hours AS sun_hours, ((((((mon.total_hours + tue.total_hours) + wed.total_hours) + thu.total_hours) + fri.total_hours) + sat.total_hours) + sun.total_hours) AS total_hours FROM ((((((hours mon LEFT JOIN hours tue ON ((((((mon.project_id = tue.project_id) AND (mon.category_id = tue.category_id)) AND (mon.member_id = tue.member_id)) AND (mon.week = tue.week)) AND (mon."year" = tue."year")))) LEFT JOIN hours wed ON ((((((mon.project_id = wed.project_id) AND (mon.category_id = wed.category_id)) AND (mon.member_id = wed.member_id)) AND (mon.week = wed.week)) AND (mon."year" = wed."year")))) LEFT JOIN hours thu ON ((((((mon.project_id = thu.project_id) AND (mon.category_id = thu.category_id)) AND (mon.member_id = thu.member_id)) AND (mon.week = thu.week)) AND (mon."year" = thu."year")))) LEFT JOIN hours fri ON ((((((mon.project_id = fri.project_id) AND (mon.category_id = fri.category_id)) AND (mon.member_id = fri.member_id)) AND (mon.week = fri.week)) AND (mon."year" = fri."year")))) LEFT JOIN hours sat ON ((((((mon.project_id = sat.project_id) AND (mon.category_id = sat.category_id)) AND (mon.member_id = sat.member_id)) AND (mon.week = sat.week)) AND (mon."year" = sat."year")))) LEFT JOIN hours sun ON ((((((mon.project_id = sun.project_id) AND (mon.category_id = sun.category_id)) AND (mon.member_id = sun.member_id)) AND (mon.week = sun.week)) AND (mon."year" = sun."year")))) WHERE (((((((mon.dow = 0) AND (tue.dow = 1)) AND (wed.dow = 2)) AND (thu.dow = 3)) AND (fri.dow = 4)) AND (sat.dow = 5)) AND (sun.dow = 6));
--
-- TOC Entry ID 12 (OID 123891)
--
-- Name: "dow_idx" Type: INDEX Owner: akm
--

CREATE  INDEX "dow_idx" on "hours" using btree ( "dow" "int4_ops" );

--
-- TOC Entry ID 13 (OID 123891)
--
-- Name: "pid_idx" Type: INDEX Owner: akm
--

CREATE  INDEX "pid_idx" on "hours" using btree ( "project_id" "int4_ops" );

--
-- TOC Entry ID 14 (OID 123891)
--
-- Name: "cid_idx" Type: INDEX Owner: akm
--

CREATE  INDEX "cid_idx" on "hours" using btree ( "category_id" "int4_ops" );

--
-- TOC Entry ID 15 (OID 123891)
--
-- Name: "mid_idx" Type: INDEX Owner: akm
--

CREATE  INDEX "mid_idx" on "hours" using btree ( "member_id" "varchar_ops" );

--
-- TOC Entry ID 16 (OID 123891)
--
-- Name: "year_idx" Type: INDEX Owner: akm
--

CREATE  INDEX "year_idx" on "hours" using btree ( "year" "int4_ops" );

--
-- TOC Entry ID 17 (OID 123891)
--
-- Name: "week_idx" Type: INDEX Owner: akm
--

CREATE  INDEX "week_idx" on "hours" using btree ( "week" "int4_ops" );

--
-- TOC Entry ID 20 (OID 123724)
--
-- Name: "RI_ConstraintTrigger_123723" Type: TRIGGER Owner: akm
--

CREATE CONSTRAINT TRIGGER "<unnamed>" AFTER INSERT OR UPDATE ON "projects"  NOT DEFERRABLE INITIALLY IMMEDIATE FOR EACH ROW EXECUTE PROCEDURE "RI_FKey_check_ins" ('<unnamed>', 'projects', 'clients', 'UNSPECIFIED', 'client_id', 'client_id');

--
-- TOC Entry ID 18 (OID 123726)
--
-- Name: "RI_ConstraintTrigger_123725" Type: TRIGGER Owner: akm
--

CREATE CONSTRAINT TRIGGER "<unnamed>" AFTER DELETE ON "clients"  NOT DEFERRABLE INITIALLY IMMEDIATE FOR EACH ROW EXECUTE PROCEDURE "RI_FKey_noaction_del" ('<unnamed>', 'projects', 'clients', 'UNSPECIFIED', 'client_id', 'client_id');

--
-- TOC Entry ID 19 (OID 123728)
--
-- Name: "RI_ConstraintTrigger_123727" Type: TRIGGER Owner: akm
--

CREATE CONSTRAINT TRIGGER "<unnamed>" AFTER UPDATE ON "clients"  NOT DEFERRABLE INITIALLY IMMEDIATE FOR EACH ROW EXECUTE PROCEDURE "RI_FKey_noaction_upd" ('<unnamed>', 'projects', 'clients', 'UNSPECIFIED', 'client_id', 'client_id');

--
-- TOC Entry ID 23 (OID 123766)
--
-- Name: "RI_ConstraintTrigger_123765" Type: TRIGGER Owner: akm
--

CREATE CONSTRAINT TRIGGER "<unnamed>" AFTER INSERT OR UPDATE ON "project_members"  NOT DEFERRABLE INITIALLY IMMEDIATE FOR EACH ROW EXECUTE PROCEDURE "RI_FKey_check_ins" ('<unnamed>', 'project_members', 'projects', 'UNSPECIFIED', 'project_id', 'project_id');

--
-- TOC Entry ID 21 (OID 123768)
--
-- Name: "RI_ConstraintTrigger_123767" Type: TRIGGER Owner: akm
--

CREATE CONSTRAINT TRIGGER "<unnamed>" AFTER DELETE ON "projects"  NOT DEFERRABLE INITIALLY IMMEDIATE FOR EACH ROW EXECUTE PROCEDURE "RI_FKey_noaction_del" ('<unnamed>', 'project_members', 'projects', 'UNSPECIFIED', 'project_id', 'project_id');

--
-- TOC Entry ID 22 (OID 123770)
--
-- Name: "RI_ConstraintTrigger_123769" Type: TRIGGER Owner: akm
--

CREATE CONSTRAINT TRIGGER "<unnamed>" AFTER UPDATE ON "projects"  NOT DEFERRABLE INITIALLY IMMEDIATE FOR EACH ROW EXECUTE PROCEDURE "RI_FKey_noaction_upd" ('<unnamed>', 'project_members', 'projects', 'UNSPECIFIED', 'project_id', 'project_id');

--
-- TOC Entry ID 24 (OID 123936)
--
-- Name: "RI_ConstraintTrigger_123935" Type: TRIGGER Owner: akm
--

CREATE CONSTRAINT TRIGGER "<unnamed>" AFTER INSERT OR UPDATE ON "hours"  NOT DEFERRABLE INITIALLY IMMEDIATE FOR EACH ROW EXECUTE PROCEDURE "RI_FKey_check_ins" ('<unnamed>', 'hours', 'projects', 'UNSPECIFIED', 'project_id', 'project_id');

--
-- TOC Entry ID 25 (OID 123938)
--
-- Name: "RI_ConstraintTrigger_123937" Type: TRIGGER Owner: akm
--

CREATE CONSTRAINT TRIGGER "<unnamed>" AFTER INSERT OR UPDATE ON "hours"  NOT DEFERRABLE INITIALLY IMMEDIATE FOR EACH ROW EXECUTE PROCEDURE "RI_FKey_check_ins" ('<unnamed>', 'hours', 'clients', 'UNSPECIFIED', 'client_id', 'client_id');

